# ;-*-mode:rpm-spec-*-
# JK: the above line tells my emacs editor to use rpm-spec mode

# avoid providing the private libs:
%global __provides_exclude_from ^(%{python3_sitearch})/.*\\.so.*$

# use grib_api for s390x aarch64
# and eccodes for the other archs since eccodes
# does not yet build for this arch
%ifarch s390x aarch64
  %global use_eccodes 0
%else
  %global use_eccodes 1
%endif

# NOTE: grib_api is not yet available for EPEL8, so
#       exclude these during the build
ExcludeArch: s390x
ExcludeArch: aarch64

Name:       pygrib
Version:    2.0.4
Release:    1%{?dist}
Summary:    Python module for reading and writing GRIB (editions 1 and 2) files

License:    MIT
URL:        https://github.com/jswhit/%{name}
Source0:    https://files.pythonhosted.org/packages/source/p/%{name}/%{name}-%{version}.tar.gz

# Adapt setup.py to not use packaged g2clib source code
Patch0: %{name}-%{version}-build.patch

# general BR
# note: build requires are global for the whole spec file
#       but the python BR packages have been sorted anyway for readibility
BuildRequires: gcc
%if 0%{?use_eccodes}
BuildRequires: eccodes-devel
%else
BuildRequires: grib_api-devel
%endif
BuildRequires: g2clib-static
# this is not yet available for EPEL8
# BuildRequires: openjpeg-devel
BuildRequires: python3-numpy

# a note on the build requirements:
# pygrib installation instructions mention these requirements:
#    $GRIBAPI_DIR, $JASPER_DIR, $OPENJPEG_DIR, $PNG_DIR and $ZLIB_DIR 
# (see https://jswhit.github.io/pygrib/docs/index.html)
#
# grib_api-devel is mentioned above.
# g2clib-devel is included in the pygrib sources, but has been removed
# to comply to Fedora policy, so has been added as requirement
# jasper-devel is BR by grib_api-devel
# libpng-devel and jasper-devel are BR for g2clib-devel
# jasper-devel BRs libjpeg-devel and others
# libpng-devel BRs zlib-devel
# However, pygrib does not need header files from these packages
# during the build, therefore no explicit BuildRequires is needed
# for jasper, openjpeg, png or zlib
#
# in addition python3-pyproj has been added as BR
# below since it is needed to run the test.py script in the check stage 

%global _description \
Cython wrapper to provide python interfaces to the grib library. \
 \
GRIB is the the World Meteorological Organization (WMO) standard for \
distributing gridded data. This module contains python interfaces for reading \
and writing GRIB data using the ECMWF GRIB API C library, and the NCEP GRIB2 \
C library, as well as command-line utilities for listing and re-packing GRIB \
files. 

%description %_description

%package -n python3-%{name}

Summary: %summary

# python3 specific
BuildRequires: python3-devel
BuildRequires: python3-numpy
BuildRequires: python3-Cython
BuildRequires: python3-pyproj

# this requirement is not automatically resolved and needs to be
# inserted manually (see bug #996834)
%if 0%{?use_eccodes}
Requires:  eccodes
%else
Requires:  grib_api
%endif

Requires:  python3-pyproj

# specifying this is not needed. rpmbuild figures it out without help
# Requires: jasper-libs openjpeg-libs libpng zlib

# ensure python provides are provided when python3 becomes the default runtime
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name} %_description

%prep
%setup -q
%patch0 -p0 -b .build

# Delete g2clib sources
rm -rf g2clib_src

# Delete precooked cython *.c files
rm  g2clib.c
rm  pygrib.c
rm  redtoreg.c

# running cython is taken care of by the setup.py
# file now, so no explicit calls are needed anymore

%build

%if 0%{?use_eccodes}
# nothing to do since v2.0.3
%else
cp setup.cfg.template setup.cfg
echo "grib_api_libname = grib_api" >> setup.cfg
%endif

# TODO: move the next 2 exports to setup.cfg
export JASPER_DIR="%{_usr}/"
export PNG_DIR="%{_usr}/"

%if 0%{?use_eccodes}
# nothing to do since v2.0.3
%else
cp setup.cfg.template setup.cfg
echo "grib_api_libname = grib_api" >> setup.cfg
%endif

%py3_build

%install

# this setting triggers installation of man pages by the setup.py file
export MAN_DIR=/usr/share/man/

%py3_install

# correct wrong write permission for group
chmod 755  %{buildroot}/%{python3_sitearch}/*.so

%check

export PYTHONPATH=%{buildroot}/%{python3_sitearch}
%{__python3} test.py

%files -n python3-%{name}
%doc COPYING PKG-INFO README.md
%doc docs ncepgrib2_docs
%{python3_sitearch}/*.so
%{python3_sitearch}/ncep*.py*
%{python3_sitearch}/__pycache__/ncep*.py*
%{python3_sitearch}/%{name}-*-py*.egg-info
%{_bindir}/cnv*
%{_bindir}/grib_*
%{_mandir}/man1/cnv*
%{_mandir}/man1/grib_*

%changelog

* Sat Nov 16 2019 Jos de Kloe <josdekloe@gmail.com> 2.0.4-1
- first version for epel8, based on f32 version
-remove optional dependency openjpeg-devel (not available yet for EPEL8)
-add excludearch statements for s390x and aarch64, since for these arhs
 eccodes is not available and the replacement grib_api is not
 yet available for EPEL8.
